package cursor_auth

import (
	"fmt"
	"os"
	"os/exec"
	"path/filepath"
	"runtime"
	"strings"
)

// ExecuteCommand 执行命令的函数
func ExecuteCommand(command string, args ...string) error {
	// 获取当前可执行文件的路径
	execPath, err := os.Executable()
	if err != nil {
		return fmt.Errorf("获取可执行文件路径失败: %v", err)
	}

	// 设置工作目录为可执行文件所在目录
	workDir := filepath.Dir(execPath)

	// 创建命令
	cmd := exec.Command(command, args...)
	cmd.Dir = workDir

	// 设置环境变量
	cmd.Env = os.Environ()

	// 在 macOS 上添加特殊处理
	if runtime.GOOS == "darwin" {
		// 添加 PATH 环境变量
		cmd.Env = append(cmd.Env, "PATH=/usr/local/bin:/usr/bin:/bin:/usr/sbin:/sbin")

		// 如果是在应用程序包内运行，需要特殊处理
		if strings.Contains(workDir, ".app/Contents/MacOS") {
			// 将工作目录设置为用户的主目录
			homeDir, err := os.UserHomeDir()
			if err == nil {
				cmd.Dir = homeDir
			}
		}
	}

	// 设置标准输出和错误输出
	cmd.Stdout = os.Stdout
	cmd.Stderr = os.Stderr

	// 执行命令
	return cmd.Run()
}
